@@ -85,8 +85,6 @@ class I2AOauth2Client:
     def get_token(self, email, password):
         url = self._get_full_url('auth/token/')
         data = {
-            "client_id": self.client_id,
-            "client_secret": self.client_secret,
             "grant_type": "password",
             "username": email,
             "password": password
@@ -99,11 +97,36 @@ class I2AOauth2Client:
         else:
             raise I2AOauth2ClientException(data=response.json())
 
+    def refresh_token(self, refresh_token):
+        url = self._get_full_url('auth/token/')
+        data = {
+            "grant_type": "refresh_token",
+            "refresh_token": refresh_token
+        }
+        response = requests.post(url, json=data, headers=self.headers)
+        if response.status_code == 200:
+            return response.json()
+        elif response.status_code == 500:
+            raise I2AOauth2ClientException(f'Refresh token attempt at {url} has failed for unknown reason.')
+        else:
+            raise I2AOauth2ClientException(data=response.json())
+
+    def revoke_token(self, token):
+        url = self._get_full_url('auth/revoke-token/')
+        data = {
+            "token": token,
+        }
+        response = requests.post(url, json=data, headers=self.headers)
+        if response.status_code == 204:
+            return
+        elif response.status_code == 500:
+            raise I2AOauth2ClientException(f'Revoke token attempt at {url} has failed for unknown reason.')
+        else:
+            raise I2AOauth2ClientException(data=response.json())
+
     def convert_token(self, backend, social_app_token):
         url = self._get_full_url('auth/convert-token/')
         data = {
-            "client_id": self.client_id,
-            "client_secret": self.client_secret,
             "grant_type": "convert_token",
             "backend": backend,
             "token": social_app_token
